@@ -18,21 +18,19 @@ class ObservationForm(ModelForm):
     start = DateTimeField(
         input_formats=['%Y-%m-%d %H:%M:%S.%f', '%Y-%m-%d %H:%M:%S'],
         error_messages={
-            'invalid':
-            'Start datetime should have either "%Y-%m-%d %H:%M:%S.%f" or "%Y-%m-%d %H:%M:%S" '
+            'invalid': 'Start datetime should have either "%Y-%m-%d %H:%M:%S.%f" or '
+            '"%Y-%m-%d %H:%M:%S" '
             'format.',
-            'required':
-            'Start datetime is required.'
+            'required': 'Start datetime is required.'
         }
     )
     end = DateTimeField(
         input_formats=['%Y-%m-%d %H:%M:%S.%f', '%Y-%m-%d %H:%M:%S'],
         error_messages={
-            'invalid':
-            'End datetime should have either "%Y-%m-%d %H:%M:%S.%f" or "%Y-%m-%d %H:%M:%S" '
+            'invalid': 'End datetime should have either "%Y-%m-%d %H:%M:%S.%f" or '
+            '"%Y-%m-%d %H:%M:%S" '
             'format.',
-            'required':
-            'End datetime is required.'
+            'required': 'End datetime is required.'
         }
     )
     ground_station = ModelChoiceField(
@@ -49,7 +47,7 @@ class ObservationForm(ModelForm):
         try:
             check_start_datetime(start)
         except ValueError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
         return start
 
     def clean_end(self):
@@ -58,7 +56,7 @@ class ObservationForm(ModelForm):
         try:
             check_end_datetime(end)
         except ValueError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
         return end
 
     def clean(self):
@@ -66,13 +64,13 @@ class ObservationForm(ModelForm):
         if any(self.errors):
             # If there are errors in fields validation no need for validating the form
             return
-        cleaned_data = super(ObservationForm, self).clean()
+        cleaned_data = super().clean()
         start = cleaned_data['start']
         end = cleaned_data['end']
         try:
             check_start_end_datetimes(start, end)
         except ValueError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
 
     class Meta:
         model = Observation
@@ -88,7 +86,7 @@ class BaseObservationFormSet(BaseFormSet):
     def __init__(self, user, *args, **kwargs):
         """Initializes Observation FormSet"""
         self.user = user
-        super(BaseObservationFormSet, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def clean(self):
         """Validates Observation FormSet data"""
@@ -119,13 +117,13 @@ class BaseObservationFormSet(BaseFormSet):
         try:
             check_overlaps(start_end_per_station)
         except ObservationOverlapError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
 
         station_list = list(set(station_list))
         try:
             check_schedule_perms_per_station(self.user, station_list)
         except UserNoPermissionError as error:
-            raise ValidationError(error, code='forbidden')
+            raise ValidationError(error, code='forbidden') from error
 
         try:
             transmitters = get_transmitters_by_uuid_set(transmitter_uuid_set)
@@ -133,9 +131,9 @@ class BaseObservationFormSet(BaseFormSet):
             norad_id_set = {transmitters[uuid]['norad_cat_id'] for uuid in transmitter_uuid_set}
             self.tle_sets = get_tle_sets_by_norad_id_set(norad_id_set)
         except ValueError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
         except DBConnectionError as error:
-            raise ValidationError(error)
+            raise ValidationError(error) from error
 
         transmitter_uuid_station_set = set(transmitter_uuid_station_list)
         transmitter_station_list = [
@@ -144,7 +142,7 @@ class BaseObservationFormSet(BaseFormSet):
         try:
             check_transmitter_station_pairs(transmitter_station_list)
         except OutOfRangeError as error:
-            raise ValidationError(error, code='invalid')
+            raise ValidationError(error, code='invalid') from error
 
 
 ObservationFormSet = formset_factory(
